| Title: | Interactive Document for Working with Analysis of Variance |
|---|---|
| Description: | An interactive document on the topic of one-way and two-way analysis of variance using 'rmarkdown' and 'shiny' packages. Runtime examples are provided in the package function as well as at <https://kartikeyab.shinyapps.io/ANOVAShiny/>. |
| Authors: | Kartikeya Bolar |
| Maintainer: | Kartikeya Bolar <[email protected]> |
| License: | GPL-2 |
| Version: | 0.1.0 |
| Built: | 2026-05-16 07:49:50 UTC |
| Source: | https://github.com/cran/ANOVAShiny |
ANOVAShiny() loads interactive user interface built using R 'shiny'.
ANOVAShiny()ANOVAShiny()
Start ANOVAShiny
The interactive user interface is to provide an easy way for anova analysis and downloading relevant plots.
Nothing
if(interactive()){ library(rmarkdown) ANOVAShiny() }if(interactive()){ library(rmarkdown) ANOVAShiny() }