Welcome to ClientVPS Mirrors

Help for package ANOVAShiny
Type: Package
Title: Interactive Document for Working with Analysis of Variance
Version: 0.1.0
Author: Kartikeya Bolar
Maintainer: Kartikeya Bolar <kartikeya.bolar@tapmi.edu.in>
Description: An interactive document on the topic of one-way and two-way analysis of variance using 'rmarkdown' and 'shiny' packages. Runtime examples are provided in the package function as well as at https://kartikeyab.shinyapps.io/ANOVAShiny/.
License: GPL-2
Encoding: UTF-8
LazyData: TRUE
Depends: R (≥ 3.0.3)
Imports: shiny,rmarkdown,dplyr,datasets,rhandsontable,DescTools,HH
RoxygenNote: 6.1.0
NeedsCompilation: no
Packaged: 2019-04-30 17:46:29 UTC; KARTIKEYA
Repository: CRAN
Date/Publication: 2019-05-01 07:00:03 UTC

Launch 'ANOVAShiny' Interface

Description

ANOVAShiny() loads interactive user interface built using R 'shiny'.

Usage

ANOVAShiny()

Details

Start ANOVAShiny

The interactive user interface is to provide an easy way for anova analysis and downloading relevant plots.

Value

Nothing

Examples

if(interactive()){
library(rmarkdown)
ANOVAShiny()
}

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.